"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cdk_1 = require("@aws-cdk/cdk");
const aws_sdk_1 = require("aws-sdk");
const lib = require("../lib");
function handleSSMSecret(params) {
    return __awaiter(this, void 0, void 0, function* () {
        const { ssmHandler, tokenName, token } = params;
        if (tokenName === undefined) {
            lib.noGithubTokenFound();
            return { name: 'noToken', secret: new cdk_1.Secret('') };
        }
        token && (yield ssmHandler.createParameter(tokenName, token));
        const value = yield ssmHandler.getParameter(tokenName);
        return { name: tokenName, secret: new cdk_1.Secret(value) };
    });
}
exports.handleSSMSecret = handleSSMSecret;
class SSMHandler {
    constructor() {
        const { credentials, region } = aws_sdk_1.config;
        this.ssm = new aws_sdk_1.SSM({ credentials, region });
    }
    getParameter(ssmName) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = { Name: ssmName, WithDecryption: true };
            const ssmParam = yield this.ssm.getParameter(params).promise();
            return (ssmParam && ssmParam.Parameter && ssmParam.Parameter.Value) || '';
        });
    }
    createParameter(name, value) {
        return __awaiter(this, void 0, void 0, function* () {
            const type = 'SecureString';
            const params = { Name: name, Overwrite: true, Type: type, Value: value };
            yield this.ssm.putParameter(params).promise();
        });
    }
}
exports.SSMHandler = SSMHandler;
//# sourceMappingURL=handle_ssm.js.map