"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("@seagull/testing");
const chai_1 = require("chai");
require("chai/register-should");
const mocha_typescript_1 = require("mocha-typescript");
const handle_ssm_1 = require("../src/aws_sdk_handler/handle_ssm");
let Test = class Test extends testing_1.BasicTest {
    before() {
        return __awaiter(this, void 0, void 0, function* () {
            yield testing_1.BasicTest.prototype.before.bind(this)();
        });
    }
    after() {
        return __awaiter(this, void 0, void 0, function* () {
            yield testing_1.BasicTest.prototype.after.bind(this)();
        });
    }
    'can set a SSMSecret via new token'() {
        return __awaiter(this, void 0, void 0, function* () {
            const ssmHandler = new TestSSMHandler();
            const params = { ssmHandler, token: '123', tokenName: 'testToken' };
            const ssmSecret = yield handle_ssm_1.handleSSMSecret(params);
            chai_1.expect(ssmSecret.name).to.be.equals('testToken');
            chai_1.expect(ssmSecret.secret.resolve()).to.be.equals('123');
        });
    }
    'can set a SSMSecret via existing token'() {
        return __awaiter(this, void 0, void 0, function* () {
            const handler = new TestSSMHandler({ testToken: 'abc' });
            const params = { ssmHandler: handler, tokenName: 'testToken' };
            const ssmSecret = yield handle_ssm_1.handleSSMSecret(params);
            chai_1.expect(ssmSecret.name).to.be.equals('testToken');
            chai_1.expect(ssmSecret.secret.resolve()).to.be.equals('abc');
        });
    }
    'can set a SSMSecret and overwrite an existing one'() {
        return __awaiter(this, void 0, void 0, function* () {
            const ssmHandler = new TestSSMHandler({ testToken: 'abc' });
            const params = { ssmHandler, token: '123', tokenName: 'testToken' };
            const ssmSecret = yield handle_ssm_1.handleSSMSecret(params);
            chai_1.expect(ssmSecret.name).to.be.equals('testToken');
            chai_1.expect(ssmSecret.secret.resolve()).to.be.equals('123');
        });
    }
    'get an invalid SSMSecret, if no same is given'() {
        return __awaiter(this, void 0, void 0, function* () {
            const ssmHandler = new TestSSMHandler();
            const params = { ssmHandler };
            const ssmSecret = yield handle_ssm_1.handleSSMSecret(params);
            chai_1.expect(ssmSecret.name).to.be.equals('noToken');
            chai_1.expect(ssmSecret.secret.resolve()).to.be.equals('');
        });
    }
};
__decorate([
    mocha_typescript_1.test,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], Test.prototype, "can set a SSMSecret via new token", null);
__decorate([
    mocha_typescript_1.test,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], Test.prototype, "can set a SSMSecret and overwrite an existing one", null);
__decorate([
    mocha_typescript_1.test,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], Test.prototype, "get an invalid SSMSecret, if no same is given", null);
Test = __decorate([
    mocha_typescript_1.suite('HandleSSMSecret')
], Test);
exports.Test = Test;
class TestSSMHandler extends handle_ssm_1.SSMHandler {
    constructor(testData) {
        super();
        this.mockStore = testData || {};
    }
    getParameter(ssmName) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.mockStore[ssmName] || '';
        });
    }
    createParameter(name, value) {
        return __awaiter(this, void 0, void 0, function* () {
            this.mockStore[name] = value;
            return;
        });
    }
}
//# sourceMappingURL=handle_ssm_secret.js.map