"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const commands_fs_1 = require("@seagull/commands-fs");
const testing_1 = require("@seagull/testing");
require("chai/register-should");
const mocha_typescript_1 = require("mocha-typescript");
const src_1 = require("../src");
let Test = class Test extends testing_1.BasicTest {
    constructor() {
        super(...arguments);
        this.tmpDir = '/tmp/tmp_for_folder_test';
        this.seagullPath = `${this.tmpDir}/.seagull`;
        this.backendInSgPath = `${this.tmpDir}/.seagull/deploy/dist/assets/backend`;
        this.filePathToTestRemoval = `${this.backendInSgPath}/remove.js`;
        this.serverInSgPath = `${this.backendInSgPath}/server.js`;
        this.lambdaInSgPath = `${this.backendInSgPath}/lambda.js`;
    }
    before() {
        return __awaiter(this, void 0, void 0, function* () {
            yield testing_1.BasicTest.prototype.before.bind(this)();
            yield this.removeTmpDir();
            yield new commands_fs_1.FS.CreateFolder(this.tmpDir).execute();
            yield this.createDistAssetDir();
        });
    }
    createDistAssetDir() {
        return __awaiter(this, void 0, void 0, function* () {
            const distBackendPath = `${this.tmpDir}/dist/assets/backend`;
            yield new commands_fs_1.FS.CreateFolder(distBackendPath).execute();
            yield new commands_fs_1.FS.WriteFile(`${distBackendPath}/server.js`, 'Server').execute();
            yield new commands_fs_1.FS.WriteFile(`${distBackendPath}/lambda.js`, 'Lambda').execute();
        });
    }
    removeTmpDir() {
        return __awaiter(this, void 0, void 0, function* () {
            const tmpDirExists = yield new commands_fs_1.FS.Exists(this.tmpDir).execute();
            return tmpDirExists && (yield new commands_fs_1.FS.DeleteFolder(this.tmpDir).execute());
        });
    }
    after() {
        return __awaiter(this, void 0, void 0, function* () {
            yield testing_1.BasicTest.prototype.after.bind(this)();
            yield this.removeTmpDir();
        });
    }
    'check whether asset folder is provided'() {
        return __awaiter(this, void 0, void 0, function* () {
            const sgFolderExists = new commands_fs_1.FS.Exists(this.seagullPath);
            const provideFolder = new src_1.ProvideAssetFolder(this.tmpDir);
            const lambdaFileExists = new commands_fs_1.FS.Exists(this.lambdaInSgPath);
            const serverFileExists = new commands_fs_1.FS.Exists(this.serverInSgPath);
            const sgFolderExistsBefore = yield sgFolderExists.execute();
            yield provideFolder.execute();
            const sgFolderExistsAfter = yield sgFolderExists.execute();
            const lambdaFileExistsResult = yield lambdaFileExists.execute();
            const serverFileExistsResult = yield serverFileExists.execute();
            sgFolderExistsBefore.should.be.equals(false);
            sgFolderExistsAfter.should.be.equals(true);
            serverFileExistsResult.should.be.equals(false);
            lambdaFileExistsResult.should.be.equals(true);
        });
    }
    'check whether asset folder is provided, when there already is one'() {
        return __awaiter(this, void 0, void 0, function* () {
            const sgFolderExists = new commands_fs_1.FS.Exists(this.seagullPath);
            const provideFolder = new src_1.ProvideAssetFolder(this.tmpDir);
            const fileRemoveExists = new commands_fs_1.FS.Exists(this.filePathToTestRemoval);
            const writeRemove = new commands_fs_1.FS.WriteFile(this.filePathToTestRemoval, 'Remove');
            const lambdaFileExists = new commands_fs_1.FS.Exists(this.lambdaInSgPath);
            const serverFileExists = new commands_fs_1.FS.Exists(this.serverInSgPath);
            const sgFolderExistsBefore = yield sgFolderExists.execute();
            yield provideFolder.execute();
            yield writeRemove.execute();
            const fileRemoveExistsBefore = yield fileRemoveExists.execute();
            yield provideFolder.execute();
            const fileRemoveExistsAfter = yield fileRemoveExists.execute();
            const lambdaFileExistsResult = yield lambdaFileExists.execute();
            const serverFileExistsResult = yield serverFileExists.execute();
            sgFolderExistsBefore.should.be.equals(false);
            fileRemoveExistsBefore.should.be.equals(true);
            fileRemoveExistsAfter.should.be.equals(false);
            serverFileExistsResult.should.be.equals(false);
            lambdaFileExistsResult.should.be.equals(true);
        });
    }
    'check whether revert works'() {
        return __awaiter(this, void 0, void 0, function* () {
            const sgFolderExists = new commands_fs_1.FS.Exists(this.seagullPath);
            const provideFolder = new src_1.ProvideAssetFolder(this.tmpDir);
            yield provideFolder.execute();
            const revertResult = yield provideFolder.revert();
            revertResult.should.be.equals(true);
        });
    }
};
__decorate([
    mocha_typescript_1.test,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], Test.prototype, "check whether asset folder is provided", null);
__decorate([
    mocha_typescript_1.test,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], Test.prototype, "check whether asset folder is provided, when there already is one", null);
__decorate([
    mocha_typescript_1.test,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], Test.prototype, "check whether revert works", null);
Test = __decorate([
    mocha_typescript_1.suite('ProvideAssetFolder')
], Test);
exports.Test = Test;
//# sourceMappingURL=provide_asset_folder.js.map