"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("@seagull/testing");
require("chai/register-should");
const mocha_typescript_1 = require("mocha-typescript");
const commands_fs_1 = require("@seagull/commands-fs");
const src_1 = require("../../src");
const Handlers = require("../../src/aws_sdk_handler");
let Test = class Test extends testing_1.BasicTest {
    constructor() {
        super(...arguments);
        this.appPath = `${process.cwd()}/test_data`;
    }
    before() {
        return __awaiter(this, void 0, void 0, function* () {
            yield testing_1.BasicTest.prototype.before.bind(this)();
            process.env.AWS_REGION = 'eu-central-1';
            const assetFolder = `${this.appPath}/dist/assets`;
            const backendFolder = `${assetFolder}/backend`;
            const createBackendFolder = new commands_fs_1.FS.CreateFolder(backendFolder);
            yield createBackendFolder.execute();
            yield new commands_fs_1.FS.WriteFile(`${backendFolder}/server.js`, '').execute();
            yield new commands_fs_1.FS.WriteFile(`${backendFolder}/lambda.js`, '').execute();
            yield new commands_fs_1.FS.WriteFile(`${this.appPath}/dist/cron.json`, JSON.stringify([])).execute();
        });
    }
    after() {
        return __awaiter(this, void 0, void 0, function* () {
            yield testing_1.BasicTest.prototype.after.bind(this)();
        });
    }
    'can create a project'() {
        return __awaiter(this, void 0, void 0, function* () {
            const props = {
                appPath: this.appPath,
                branch: 'master',
                githubToken: 'Token123',
                handlers: {
                    acmHandler: new TestACMHandler(),
                    cloudfrontHandler: new TestCloudfrontHandler(),
                    stsHandler: new TestSTSHandler(),
                },
                mode: 'prod',
                owner: 'me',
                profile: 'default',
                region: 'eu-central-1',
                repository: 'test-repo',
            };
            const project = yield new src_1.SeagullProject(props).createSeagullApp();
            const synthStack = project.synthesizeStack('helloworld');
            Object.keys(synthStack.template.Resources).length.should.be.above(1);
        });
    }
};
__decorate([
    mocha_typescript_1.test,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], Test.prototype, "can create a project", null);
Test = __decorate([
    mocha_typescript_1.suite('SeagullProject')
], Test);
exports.Test = Test;
class TestACMHandler extends Handlers.ACMHandler {
    constructor(testData) {
        super();
        this.arnsWithDomains = testData || { arn1: ['www.aida.de', 'www2.aida.de'] };
    }
    listCertificates() {
        return __awaiter(this, void 0, void 0, function* () {
            return Object.keys(this.arnsWithDomains);
        });
    }
    describeCertificate(acmCertRef) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.arnsWithDomains[acmCertRef] || [];
        });
    }
}
class TestCloudfrontHandler extends Handlers.CloudfrontHandler {
    constructor(testData) {
        super();
        const defaultData = [{ Comment: 'helloworld', DomainName: 'abcdef.cf.net' }];
        this.cloudfrontList = testData || defaultData;
    }
    listDistributions() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.cloudfrontList;
        });
    }
}
class TestSTSHandler extends Handlers.STSHandler {
    constructor(testAccount) {
        super();
        this.accountId = testAccount || 'test-account-id';
    }
    getAccountId() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.accountId;
        });
    }
}
//# sourceMappingURL=seagull_project.js.map